@@ -53,12 +53,6 @@ test_that("test ntype tokens", {
     expect_identical(ntype(toks2), c(d1 = 2L, d2 = 4L))
 })
 
-test_that("deprecated nfeature still works", {
-    suppressWarnings(
-        expect_error(nfeature(data_dfm_lbgexample), "Use 'nfeat' instead")
-    )
-})
-
 test_that("dots are applied in ntokens.tokens, ntype.tokens", {
     txt <- c(d1 = "3 wonderful tokens of the tokens function.")
     toks <- tokens(txt)
@@ -66,12 +60,12 @@ test_that("dots are applied in ntokens.tokens, ntype.tokens", {
     expect_identical(ntoken(toks), c(d1 = 8L))
     expect_identical(ntoken(toks, remove_punct = TRUE), c(d1 = 7L))
     expect_identical(ntoken(toks, remove_punct = TRUE, remove_numbers = TRUE), c(d1 = 6L))
-    expect_warning(ntoken(toks, notarg = TRUE), "notarg not used")
+    expect_warning(ntoken(toks, notarg = TRUE), "^notarg argument is not used")
     
     expect_identical(ntype(toks), c(d1 = 7L))
     expect_identical(ntype(toks, remove_punct = TRUE), c(d1 = 6L))
     expect_identical(ntype(toks, remove_punct = TRUE, remove_numbers = TRUE), c(d1 = 5L))
-    expect_warning(ntype(toks, notarg = TRUE), "notarg not used")
+    expect_warning(ntype(toks, notarg = TRUE), "^notarg argument is not used")
     
     expect_identical(ntype(txt, remove_punct = TRUE), c(d1 = 6L))
     expect_identical(ntype(txt), c(d1 = 7L))
