@@ -171,3 +171,15 @@ test_that("sample_bygroup works with groups of size 1", {
         expect_equal(tmp[4], 4)
     }
 })
+
+test_that("max_load_factor can be configured", {
+    quanteda:::qatd_cpp_set_load_factor("pattern", 0.2)
+    quanteda:::qatd_cpp_set_load_factor("pattern", -1.0)
+    quanteda:::qatd_cpp_set_load_factor("pattern", 2.0)
+    quanteda:::qatd_cpp_set_load_factor("ngrams", 0.7)
+    quanteda:::qatd_cpp_set_load_factor("ngrams", -1.0)
+    quanteda:::qatd_cpp_set_load_factor("ngrams", 2.0)
+    expect_equal(quanteda:::qatd_cpp_get_load_factor(),
+                 list(pattern = 0.2, ngrams = 0.7), tolerance = 0.001)
+    
+})
